==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAdministratorsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAdministratorsManager::BEGIN{package NXAdministratorsManager;no warnings;
require NXPaths;do{"\x4e\x58\x50\x61\x74\x68\x73"->import};}package 
NXAdministratorsManager;no warnings;%isAdministrator;sub put{(my $username=shift
 (@_));if ((length ($username)==(0x0237+ 4092-0x1233))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($username=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$username).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}if (userExistInDb ($username)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x55\x73\x65\x72\x41\x6c\x72\x65\x61\x64\x79\x49\x6e\x44\x42"
->throw ((("\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x3a\x20".
$username).
"\x20\x69\x73\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x69\x6e\x20\x74\x68\x65\x20\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x20\x44\x42"
));}NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($username))."\x0a"));return ((0x0dff+ 5218-0x2260));}sub del{(my $field
=shift (@_));if ((not (defined ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if ((length ($field)==(0x027c+ 5634-0x187e))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ s/^login=// )){if ((length ($field)==(0x1196+ 899-0x1519))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$field).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}}($field=NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($field));if ((not
 (userExistInDb ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f"->throw (((
"\x55\x73\x65\x72\x3a\x20".$field).
"\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x20\x69\x6e\x20\x74\x68\x65\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x64\x61\x74\x61\x62\x61\x73\x65\x2e"
));}else{NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($field))."\x0a"));}return;}sub list{(my (@users)=());
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $login_line=NXRedis::get ());(my (@administrators)=());if ((defined (
$login_line)and (length ($login_line)!=(0x09c2+ 1122-0x0e24)))){(@users=split ( / / ,
$login_line,(0x03c5+ 5933-0x1af2)));foreach my $administrator (@users){push (
@administrators,main::urldecode ($administrator));}}return (@administrators);}
sub userExistInDb{(my $username=shift (@_));($username=
NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($username));if (defined (
$isAdministrator{$username})){return ($isAdministrator{$username});}(my (
@userlist)=list ());($isAdministrator{$username}=(0x150a+ 4199-0x2571));foreach my $userData
 (@userlist){($userData=NXLogin::getAbsoluteNameForUsernameIfNotDisabled (
$userData));($isAdministrator{$userData}=(0x0a95+ 1672-0x111c));}return (
$isAdministrator{$username});}sub userIsAdministrator{(my $user=shift (@_));if (
(defined ($user)and ($user ne ("")))){if (userExistInDb ($user)){return (
(0x0712+ 6312-0x1fb9));}if (Common::NXCore::userIsSystemAdministrator ($user)){
return ((0x1dc6+ 1167-0x2254));}}return ((0x10c3+ 784-0x13d3));}sub 
userIsNXAdministrator{(my $user=shift (@_));if ((defined ($user)and ($user ne 
("")))){if (userExistInDb ($user)){return ((0x09b9+ 1599-0x0ff7));}}return (
(0x23f9+ 611-0x265c));}sub printAdministratorList{(my $kindrequest=
"\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x6c\x69\x73\x74"
);NXMsg::send_response ("\x69\x43\x4d\x44\x55\x73\x65\x72\x6c\x69\x73\x74",
"\x4e\x58\x55\x73\x65\x72\x73\x4d\x61\x6e\x61\x67\x65\x72",$kindrequest);
main::nxwrite (main::nxgetSTDOUT (),
"\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x0a"
);(my (@userlist)=list ());foreach my $user_line (@userlist){(my $username=
sprintf ("\x25\x2d\x33\x32\x73",$user_line));main::nxwrite (main::nxgetSTDOUT ()
,($username."\x0a"));}main::nxwrite (main::nxgetSTDOUT (),"\x0a");return (
(0x0d7c+ 2288-0x166c));}sub reloadAdministratorsDB{((%isAdministrator)=());}sub 
getDatabaseInString{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $adminsList=NXRedis::get ());($adminsList=~ s/ /,/g );return ($adminsList)
;}sub cleanDb{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);}sub setDatabaseByString{(my $string=shift (@_));(my (@administrators)=split ( /,/ ,
$string,(0x0f12+ 278-0x1028)));if ((scalar (@administrators)==
(0x0911+ 745-0x0bfa))){return ((0x0279+ 1613-0x08c6));}(my $redisString=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73"
);foreach my $admin (@administrators){($redisString.=(
"\x2c\x66\x69\x65\x6c\x64\x3d".$admin));}($redisString.="\x0a");
NXRedis::sendToDb ($redisString);return ((0x0219+ 740-0x04fd));}"\x3f\x3f\x3f";

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAdministratorsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAdministratorsManager::BEGIN{package NXAdministratorsManager;no warnings;
require NXPaths;do{"\x4e\x58\x50\x61\x74\x68\x73"->import};}package 
NXAdministratorsManager;no warnings;%isAdministrator;sub put{(my $username=shift
 (@_));if ((length ($username)==(0x04c4+ 2352-0x0df4))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($username=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$username).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}if (userExistInDb ($username)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x55\x73\x65\x72\x41\x6c\x72\x65\x61\x64\x79\x49\x6e\x44\x42"
->throw ((("\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x3a\x20".
$username).
"\x20\x69\x73\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x69\x6e\x20\x74\x68\x65\x20\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x20\x44\x42"
));}NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($username))."\x0a"));return ((0x072b+ 2927-0x1299));}sub del{(my $field
=shift (@_));if ((not (defined ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if ((length ($field)==(0x0156+ 4198-0x11bc))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ s/^login=// )){if ((length ($field)==(0x15c6+ 1914-0x1d40))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$field).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}}($field=NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($field));if ((not
 (userExistInDb ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f"->throw (((
"\x55\x73\x65\x72\x3a\x20".$field).
"\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x20\x69\x6e\x20\x74\x68\x65\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x64\x61\x74\x61\x62\x61\x73\x65\x2e"
));}else{NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($field))."\x0a"));}return;}sub list{(my (@users)=());
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $login_line=NXRedis::get ());(my (@administrators)=());if ((defined (
$login_line)and (length ($login_line)!=(0x1ed2+ 1868-0x261e)))){(@users=split ( / / ,
$login_line,(0x1694+ 2913-0x21f5)));foreach my $administrator (@users){push (
@administrators,main::urldecode ($administrator));}}return (@administrators);}
sub userExistInDb{(my $username=shift (@_));($username=
NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($username));if (defined (
$isAdministrator{$username})){return ($isAdministrator{$username});}(my (
@userlist)=list ());($isAdministrator{$username}=(0x11cf+ 3212-0x1e5b));foreach my $userData
 (@userlist){($userData=NXLogin::getAbsoluteNameForUsernameIfNotDisabled (
$userData));($isAdministrator{$userData}=(0x151b+ 2250-0x1de4));}return (
$isAdministrator{$username});}sub userIsAdministrator{(my $user=shift (@_));if (
(defined ($user)and ($user ne ("")))){if (userExistInDb ($user)){return (
(0x19b4+ 2259-0x2286));}if (Common::NXCore::userIsSystemAdministrator ($user)){
return ((0x1155+ 1742-0x1822));}}return ((0x0217+ 5285-0x16bc));}sub 
userIsNXAdministrator{(my $user=shift (@_));if ((defined ($user)and ($user ne 
("")))){if (userExistInDb ($user)){return ((0x1632+ 531-0x1844));}}return (
(0x0824+ 348-0x0980));}sub printAdministratorList{(my $kindrequest=
"\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x6c\x69\x73\x74"
);NXMsg::send_response ("\x69\x43\x4d\x44\x55\x73\x65\x72\x6c\x69\x73\x74",
"\x4e\x58\x55\x73\x65\x72\x73\x4d\x61\x6e\x61\x67\x65\x72",$kindrequest);
main::nxwrite (main::nxgetSTDOUT (),
"\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x0a"
);(my (@userlist)=list ());foreach my $user_line (@userlist){(my $username=
sprintf ("\x25\x2d\x33\x32\x73",$user_line));main::nxwrite (main::nxgetSTDOUT ()
,($username."\x0a"));}main::nxwrite (main::nxgetSTDOUT (),"\x0a");return (
(0x20bb+  46-0x20e9));}sub reloadAdministratorsDB{((%isAdministrator)=());}sub 
getDatabaseInString{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $adminsList=NXRedis::get ());($adminsList=~ s/ /,/g );return ($adminsList)
;}sub cleanDb{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);}sub setDatabaseByString{(my $string=shift (@_));(my (@administrators)=split ( /,/ ,
$string,(0x1161+ 3387-0x1e9c)));if ((scalar (@administrators)==
(0x0081+ 7588-0x1e25))){return ((0x071f+ 4860-0x1a1b));}(my $redisString=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73"
);foreach my $admin (@administrators){($redisString.=(
"\x2c\x66\x69\x65\x6c\x64\x3d".$admin));}($redisString.="\x0a");
NXRedis::sendToDb ($redisString);return ((0x1bab+ 2637-0x25f8));}"\x3f\x3f\x3f";
